@@ -37,7 +37,7 @@ import os
 # the command line option --mlhub.
 # ------------------------------------------------------------------------
 
-MLHUB = "https://mlhub.ai/"
+MLHUB = "https://mlhub.au/"
 if "MLHUB" in os.environ:
     # The following adds a trailing "/" as assumed in the code.
     MLHUB = os.path.join(os.getenv("MLHUB"), "")
@@ -85,7 +85,7 @@ CMD = "ml"  # The command line tool.
 EXT_MLM = ".mlm"  # Archive filename extension
 EXT_AIPK = ".aipk"  # Backward compatibility
 
-VERSION = "3.11.0"  # DO NOT MODIFY. Managed from ../Makefile.
+VERSION = "3.11.3"  # DO NOT MODIFY. Managed from ../Makefile.
 
 OPTIONS = {
     # Global command line options
